Package: islify
Title: Automatic scoring and classification of cell-based assay images
Version: 1.4.0
Date: 2025-09-03
biocViews:
        Software,CellBasedAssays,BiomedicalInformatics,FeatureExtraction,
        Visualization,Pathways,Classification
Authors@R: 
    person('Jakob', 'Theorell', email = "jakob.theorell@ki.se",
        role = c("aut", "cre", "fnd"), comment=c(ORCID="0000-0001-8752-3151",
        "Funding provided by the Swedish Wenner-Gren Foundations"))
Description: This software is meant to be used for classification of images of
    cell-based assays for neuronal surface autoantibody detection or similar
    techniques. It takes imaging files as input and creates a composite score
    from these, that for example can be used to classify samples as negative or
    positive for a certain antibody-specificity. The reason for its name is
    that I during its creation have thought about the individual picture as an
    archielago where we with different filters control the water level as well
    as ground characteristica, thereby finding islands of interest. 
License: GPL-3
URL: https://github.com/Bioconductor/islify
BugReports: https://github.com/Bioconductor/islify/issues
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 4.5)
Imports: autothresholdr (>= 1.4.2), Matrix (>= 1.6.1), RBioFormats (>=
        1.0.0), tiff (>= 0.1.12), png (>= 0.1.8), dbscan (>= 1.1.12),
        abind (>= 1.4.8), methods (>= 4.3.3), stats (>= 4.3.3)
Suggests: knitr, rmarkdown, testthat, BiocStyle
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/islify
git_branch: RELEASE_3_23
git_last_commit: 6cda47f
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:49:32 UTC; biocbuild
Author: Jakob Theorell [aut, cre, fnd] (ORCID:
    <https://orcid.org/0000-0001-8752-3151>, Funding provided by the
    Swedish Wenner-Gren Foundations)
Maintainer: Jakob Theorell <jakob.theorell@ki.se>
