# Generated by roxygen2: do not edit by hand

export(getIntensityCutoff)
export(getQuantileIntensities)
export(getSizeCutoff)
export(islify)
export(saveImage)
export(zprime)
importFrom(Matrix,Matrix)
importFrom(Matrix,sparseMatrix)
importFrom(Matrix,summary)
importFrom(RBioFormats,read.image)
importFrom(abind,abind)
importFrom(autothresholdr,auto_thresh)
importFrom(dbscan,dbscan)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,new)
importFrom(png,readPNG)
importFrom(png,writePNG)
importFrom(stats,cov)
importFrom(stats,mad)
importFrom(stats,mahalanobis)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(tiff,readTIFF)
