#' Automatic scoring and classification of cell-based assay images
#'
#' @description This software is meant to be used for classification of images
#' of cell-based assays for neuronal surface autoantibody detection or similar
#' techniques. It takes imaging files as input and creates a composite score
#' from these, that for example can be used to classify samples as negative or
#' positive for a certain antibody-specificity. The reason for its name is that
#' I during its creation have envisioned the individual picture as an
#' archielago where we with different filters control the water level, and
#' thereby define islands with differing sizes and characteristics.
#'
#' @name islify-package
#' @author
#' Maintainer: Jakob Theorell <jakob.theorell@@ki.se>
#' @keywords package
"_PACKAGE"
# > [1] '_PACKAGE'
NULL
