#' A few CASPR2-negative cells
#'
#' This is a negative control image, used for help functions and vignettes. It
#' is a real-life image showing CASPR2 expressing HEK293-MSC cells co-incubated
#' with CASPR2-IgG. It was generated by Dr Amanda Freitas Huhtamäki during her
#' postdoctoral period in the Jakob Theorell team, Center for Infectious 
#' Medicine, Department of Medicine Huddinge, in the Live Cell Imaging core 
#' facility, Huddinge, both Karolinska Institutet, Sweden. 
#'
#' @docType data
#'
#' @usage data("negImage")
#'
#' @format An a x b x c array representing red (IgG), green (GFP) and
#' blue (DAPI) colors.
#'
#' @keywords datasets
"negImage"
